==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/TomorrowExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { TomorrowExpressionDescription } from "./TomorrowExpressionDescription";
/**
 * @hidden
 */
export let TomorrowExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class TomorrowExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (TomorrowExpressionDescriptionMetadata.a == null) {
                TomorrowExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TomorrowExpressionDescriptionMetadata.c(TomorrowExpressionDescriptionMetadata.a);
            }
            if (a.j(TomorrowExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(TomorrowExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            TomorrowExpressionDescriptionMetadata.b(a);
            a.aa("TomorrowExpression", () => new TomorrowExpressionDescription());
            a.z("TomorrowExpression", TomorrowExpressionDescriptionMetadata.a);
        }
    }
    TomorrowExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(TomorrowExpressionDescriptionMetadata, 'TomorrowExpressionDescriptionMetadata');
    TomorrowExpressionDescriptionMetadata.a = null;
    return TomorrowExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/TomorrowExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { TomorrowExpressionDescription } from "./TomorrowExpressionDescription";
/**
 * @hidden
 */
export let TomorrowExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class TomorrowExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (TomorrowExpressionDescriptionMetadata.a == null) {
                TomorrowExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TomorrowExpressionDescriptionMetadata.c(TomorrowExpressionDescriptionMetadata.a);
            }
            if (a.k(TomorrowExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(TomorrowExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            TomorrowExpressionDescriptionMetadata.b(a);
            a.ac("TomorrowExpression", () => new TomorrowExpressionDescription());
            a.ab("TomorrowExpression", TomorrowExpressionDescriptionMetadata.a);
        }
    }
    TomorrowExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(TomorrowExpressionDescriptionMetadata, 'TomorrowExpressionDescriptionMetadata');
    TomorrowExpressionDescriptionMetadata.a = null;
    return TomorrowExpressionDescriptionMetadata;
})();
